Groups | Search | Server Info | Keyboard shortcuts | Login | Register [http] [https] [nntp] [nntps]


Groups > linux.debian.user > #241550 > unrolled thread

Debian 9 on H410 hardware

Started byaltech@emypeople.net
First post2021-10-21 13:10 +0200
Last post2021-10-21 17:40 +0200
Articles 11 — 9 participants

Back to article view | Back to linux.debian.user


Contents

  Debian 9 on H410 hardware altech@emypeople.net - 2021-10-21 13:10 +0200
    Re: Debian 9 on H410 hardware Dan Ritter <dsr@randomstring.org> - 2021-10-21 14:30 +0200
      Re: Debian 9 on H410 hardware Greg Wooledge <greg@wooledge.org> - 2021-10-21 15:30 +0200
        Re: Debian 9 on H410 hardware Felix Miata <mrmazda@earthlink.net> - 2021-10-21 19:00 +0200
          Re: Debian 9 on H410 hardware / Upgraded to 11 - Zenity width quirk Allen Hoover <altech@emypeople.net> - 2021-11-17 17:00 +0100
            Re: Debian 9 on H410 hardware / Upgraded to 11 - Zenity width quirk David Wright <deblis@lionunicorn.co.uk> - 2021-11-17 17:10 +0100
              Re: Debian 9 on H410 hardware / Upgraded to 11 - Zenity width quirk Brian <ad44@cityscape.co.uk> - 2021-11-17 20:40 +0100
            Re: Debian 9 on H410 hardware / Upgraded to 11 - Zenity width quirk Greg Wooledge <greg@wooledge.org> - 2021-11-17 17:10 +0100
      Re: Debian 9 on H410 hardware Allen Hoover <altech@emypeople.net> - 2021-10-21 15:30 +0200
    Re: Debian 9 on H410 hardware Andrei POPESCU <andreimpopescu@gmail.com> - 2021-10-21 15:00 +0200
    Re: Debian 9 on H410 hardware "Andrew M.A. Cater" <amacater@einval.com> - 2021-10-21 17:40 +0200

#241550 — Debian 9 on H410 hardware

Fromaltech@emypeople.net
Date2021-10-21 13:10 +0200
SubjectDebian 9 on H410 hardware
Message-ID<DaE7o-1aT-23@gated-at.bofh.it>
In general I'm wondering if it is possible to upgrade an older Debian 
system to be compatible with newer hardware, without upgrading the whole 
system to a later Debian version?


In particular, I'm wishing to get a Debian 9 system to run on an MSI 
H410M-PRO-C board, with an Intel Pentium G6405 CPU.  Have updated to 
latest backport kernel, and firmware packages.  For the most part 
everything works fine, however Xorg is falling back to using fbdev 
graphic driver.


This system is used in an offline application, and I'm not ready to 
upgrade to Debian 11 at this time.


Thanks, Allen

Please CC me.  I only get the debian-digest mailings

[toc] | [next] | [standalone]


#241551

FromDan Ritter <dsr@randomstring.org>
Date2021-10-21 14:30 +0200
Message-ID<DaFmN-1OW-1@gated-at.bofh.it>
In reply to#241550
altech@emypeople.net wrote: 
> In general I'm wondering if it is possible to upgrade an older Debian 
> system to be compatible with newer hardware, without upgrading the whole 
> system to a later Debian version?
> 
> 
> In particular, I'm wishing to get a Debian 9 system to run on an MSI 
> H410M-PRO-C board, with an Intel Pentium G6405 CPU.  Have updated to 
> latest backport kernel, and firmware packages.  For the most part 
> everything works fine, however Xorg is falling back to using fbdev 
> graphic driver.
> 
> 
> This system is used in an offline application, and I'm not ready to 
> upgrade to Debian 11 at this time.

Do you have a backport xserver-xorg-video-intel ? That's usually
the determining factor for X11 issues like this.

The other thing would be -- have you explicitly set the driver
to be intel in xorg.conf?

If neither of those things work, you should upgrade to 10 and
then 11.

-dsr-

[toc] | [prev] | [next] | [standalone]


#241558

FromGreg Wooledge <greg@wooledge.org>
Date2021-10-21 15:30 +0200
Message-ID<DaGiS-2rG-5@gated-at.bofh.it>
In reply to#241551
On Thu, Oct 21, 2021 at 09:03:43AM -0400, Allen Hoover wrote:
> On Thu, Oct 21, 2021 at 08:09:20AM -0400, Dan Ritter wrote:
> > altech@emypeople.net wrote: 
> > > In particular, I'm wishing to get a Debian 9 system to run on an MSI 
> > > H410M-PRO-C board, with an Intel Pentium G6405 CPU.

> > Do you have a backport xserver-xorg-video-intel ? That's usually
> > the determining factor for X11 issues like this.

> The xserver-xorg-video-intel package description says use of it is 
> discouraged on hardware newer than 2007.  I thought the built in 
> modesetting driver is used for intel hardware?

So... that name is confusing as all hell, isn't it.  I just Googled it,
and it turns out the full name of the CPU is "Intel Pentium Gold G6405"
and it was released this year.

I completely fail to understand Intel's branding strategy here.  It
sounds like something ancient ("Pentium"), but apparently "Pentium Gold"
is something new.  If they wanted it to sound new, they failed.

Now, knowing that this is a piece of hardware that was released in 2021,
I would *not* attempt to run Debian 9 on it.  You *might* be able to
run Debian 11 on it, if you're lucky!

[toc] | [prev] | [next] | [standalone]


#241565

FromFelix Miata <mrmazda@earthlink.net>
Date2021-10-21 19:00 +0200
Message-ID<DaJA6-4sJ-9@gated-at.bofh.it>
In reply to#241558
Greg Wooledge composed on 2021-10-21 09:27 (UTC-0400):

> Now, knowing that this is a piece of hardware that was released in 2021,
> I would *not* attempt to run Debian 9 on it.  You *might* be able to
> run Debian 11 on it, if you're lucky! 						
											
Early 2021 (Q1) is when that particular G6405 model was launched[1], but it's a
Comet Lake, which was originally launched August 21, 2019[2], so should be
Stretch-compatible at least via backports.

[1]
<https://ark.intel.com/content/www/us/en/ark/products/201901/intel-pentium-gold-g6405-processor-4m-cache-4-10-ghz.html>
[2] <https://en.wikipedia.org/wiki/Comet_Lake_%28microprocessor%29>
-- 
Evolution as taught in public schools is, like religion,
	based on faith, not based on science.

 Team OS/2 ** Reg. Linux User #211409 ** a11y rocks!

Felix Miata

[toc] | [prev] | [next] | [standalone]


#242221 — Re: Debian 9 on H410 hardware / Upgraded to 11 - Zenity width quirk

FromAllen Hoover <altech@emypeople.net>
Date2021-11-17 17:00 +0100
SubjectRe: Debian 9 on H410 hardware / Upgraded to 11 - Zenity width quirk
Message-ID<DkvvP-fa-7@gated-at.bofh.it>
In reply to#241565
On Thu, Oct 21, 2021 at 12:59:35PM -0400, Felix Miata wrote:
> Greg Wooledge composed on 2021-10-21 09:27 (UTC-0400):
> 
> > Now, knowing that this is a piece of hardware that was released in 2021,
> > I would *not* attempt to run Debian 9 on it.  You *might* be able to
> > run Debian 11 on it, if you're lucky! 						
> 											
> Early 2021 (Q1) is when that particular G6405 model was launched[1], but it's a
> Comet Lake, which was originally launched August 21, 2019[2], so should be
> Stretch-compatible at least via backports.
> 
> [1]
> <https://ark.intel.com/content/www/us/en/ark/products/201901/intel-pentium-gold-g6405-processor-4m-cache-4-10-ghz.html>
> [2] <https://en.wikipedia.org/wiki/Comet_Lake_%28microprocessor%29>

I was able to get Debian 9 mostly compatible, by using the latest 5.X 
kernel, however, opengl didn't seem to be supported.  So instead of 
trying to patch that up, I bit the bullet and upgraded to 10, then to 
11.

Now everything seems to be fully compatible. GL version shows 4.6, and 
GL Renderer is Mesa Intel(R) UHD Graphics 610.


I use a number of zenity dialogs for showing info or asking questions on 
this system.  On the Deb 9 system, these dialogs displayed with a 
reasonable width/height, without explicitly setting either --width or 
--height options.  However, after upgrading, I noticed the info, 
warning, and question dialogs display only about 10 text characters per 
line.  For instance, zenity --info --text "The quick brown fox jumped 
over the lazy dogs", displays in 5 rows, instead of in 1 row like it 
used to before upgrading.  The behaviour is the same on a fresh install 
of 11.

Was curious if anyone else had issues with this, and if there is a way 
to change the default behaviour.  Or do I need to go through and add 
--width and --height options in every instance where zenity is used?

Thanks!
Allen

[toc] | [prev] | [next] | [standalone]


#242222 — Re: Debian 9 on H410 hardware / Upgraded to 11 - Zenity width quirk

FromDavid Wright <deblis@lionunicorn.co.uk>
Date2021-11-17 17:10 +0100
SubjectRe: Debian 9 on H410 hardware / Upgraded to 11 - Zenity width quirk
Message-ID<DkvFv-xW-1@gated-at.bofh.it>
In reply to#242221
On Wed 17 Nov 2021 at 10:35:20 (-0500), Allen Hoover wrote:
> I use a number of zenity dialogs for showing info or asking questions on 
> this system.  On the Deb 9 system, these dialogs displayed with a 
> reasonable width/height, without explicitly setting either --width or 
> --height options.  However, after upgrading, I noticed the info, 
> warning, and question dialogs display only about 10 text characters per 
> line.  For instance, zenity --info --text "The quick brown fox jumped 
> over the lazy dogs", displays in 5 rows, instead of in 1 row like it 
> used to before upgrading.  The behaviour is the same on a fresh install 
> of 11.
> 
> Was curious if anyone else had issues with this, and if there is a way 
> to change the default behaviour.  Or do I need to go through and add 
> --width and --height options in every instance where zenity is used?

Search for   width   in /usr/share/doc/zenity/changelog.gz and you
will see various entries concerning this (fixes, failed fixes?).
I can't judge whether the solution is there (I hadn't heard of
zenity until today).

Cheers,
David.

[toc] | [prev] | [next] | [standalone]


#242224 — Re: Debian 9 on H410 hardware / Upgraded to 11 - Zenity width quirk

FromBrian <ad44@cityscape.co.uk>
Date2021-11-17 20:40 +0100
SubjectRe: Debian 9 on H410 hardware / Upgraded to 11 - Zenity width quirk
Message-ID<DkyWK-2wA-11@gated-at.bofh.it>
In reply to#242222
On Wed 17 Nov 2021 at 10:03:55 -0600, David Wright wrote:

[...]

I di not think my comment will psrticularly help the Op.

> I can't judge whether the solution is there (I hadn't heard of
> zenity until today).

zenity constructs dialog boxes from shell scripts. On one of my systems
it would bring in 216M of packages. It would not pass the GW standard
as being fit for use.

yad requires 29M. This is closer to the GW specifications. I can imagine
it would get a thumbs up.

dialog also constucts dialog boxes from shell scripts. It is something I
use extensively. 0M of packages required on my system. The GW criteria
would rate it at 100/100.

-- 
Brian.

[toc] | [prev] | [next] | [standalone]


#242223 — Re: Debian 9 on H410 hardware / Upgraded to 11 - Zenity width quirk

FromGreg Wooledge <greg@wooledge.org>
Date2021-11-17 17:10 +0100
SubjectRe: Debian 9 on H410 hardware / Upgraded to 11 - Zenity width quirk
Message-ID<DkvFw-xW-9@gated-at.bofh.it>
In reply to#242221
On Wed, Nov 17, 2021 at 10:35:20AM -0500, Allen Hoover wrote:
> line.  For instance, zenity --info --text "The quick brown fox jumped 
> over the lazy dogs", displays in 5 rows, instead of in 1 row like it 
> used to before upgrading.  The behaviour is the same on a fresh install 
> of 11.
> 
> Was curious if anyone else had issues with this, and if there is a way 
> to change the default behaviour.  Or do I need to go through and add 
> --width and --height options in every instance where zenity is used?

The man page says the real documentation is in GNOME.  Ugh.  Gack.
This is *repulsive*!

So, working with what limited information they *deigned* to put in the
man page, --info says it displays an "info dialog", whatever that is.
Then under "Info options" there are only three choices:

       --text=STRING
              Set the dialog text

       --no-wrap
              Do not enable text wrapping

       --no-markup
              Do not enable pango markup

Adding --no-wrap makes it show up in a single line instead of multiple
lines, at least on my system.  And using --text="..." vs. --text "..."
seems to make no difference, with or without --no-wrap.

Sorry, that's all the information I can dig up, because I do not run
freaking GNOME and therefore cannot read the freaking documentation.
If you want to know things like "how to change the default options" or
"how to remain backward compatible with previous versions of Zenity
and/or GTK" or "what the hell an info dialog is", apparently you have
to run GNOME.

[toc] | [prev] | [next] | [standalone]


#241559

FromAllen Hoover <altech@emypeople.net>
Date2021-10-21 15:30 +0200
Message-ID<DaGiS-2rG-7@gated-at.bofh.it>
In reply to#241551
On Thu, Oct 21, 2021 at 08:09:20AM -0400, Dan Ritter wrote:
> altech@emypeople.net wrote: 
> > In general I'm wondering if it is possible to upgrade an older Debian 
> > system to be compatible with newer hardware, without upgrading the whole 
> > system to a later Debian version?
> > 
> > 
> > In particular, I'm wishing to get a Debian 9 system to run on an MSI 
> > H410M-PRO-C board, with an Intel Pentium G6405 CPU.  Have updated to 
> > latest backport kernel, and firmware packages.  For the most part 
> > everything works fine, however Xorg is falling back to using fbdev 
> > graphic driver.
> > 
> > 
> > This system is used in an offline application, and I'm not ready to 
> > upgrade to Debian 11 at this time.
> 
> Do you have a backport xserver-xorg-video-intel ? That's usually
> the determining factor for X11 issues like this.
> 
> The other thing would be -- have you explicitly set the driver
> to be intel in xorg.conf?
> 
> If neither of those things work, you should upgrade to 10 and
> then 11.
> 
> -dsr-

The xserver-xorg-video-intel package description says use of it is 
discouraged on hardware newer than 2007.  I thought the built in 
modesetting driver is used for intel hardware?

[toc] | [prev] | [next] | [standalone]


#241554

FromAndrei POPESCU <andreimpopescu@gmail.com>
Date2021-10-21 15:00 +0200
Message-ID<DaFPQ-1Zq-5@gated-at.bofh.it>
In reply to#241550

[Multipart message — attachments visible in raw view] — view raw

On Jo, 21 oct 21, 06:35:30, altech@emypeople.net wrote:
> In general I'm wondering if it is possible to upgrade an older Debian 
> system to be compatible with newer hardware, without upgrading the whole 
> system to a later Debian version?
> 
> 
> In particular, I'm wishing to get a Debian 9 system to run on an MSI 
> H410M-PRO-C board, with an Intel Pentium G6405 CPU.  Have updated to 
> latest backport kernel, and firmware packages.  For the most part 
> everything works fine, however Xorg is falling back to using fbdev 
> graphic driver.

You could try manually installing only the kernel from bullseye (Debian 
11) or buster-backports if that doesn't work out.

In general Debian is very flexible in using an older or newer kernel and 
as far as I can tell the dependencies for the kernel in bullseye are 
satisfied in stretch.

Hope this helps,
Andrei
-- 
http://wiki.debian.org/FAQsFromDebianUser

[toc] | [prev] | [next] | [standalone]


#241562

From"Andrew M.A. Cater" <amacater@einval.com>
Date2021-10-21 17:40 +0200
Message-ID<DaIaZ-3JN-1@gated-at.bofh.it>
In reply to#241550
On Thu, Oct 21, 2021 at 06:35:30AM -0400, altech@emypeople.net wrote:
> In general I'm wondering if it is possible to upgrade an older Debian 
> system to be compatible with newer hardware, without upgrading the whole 
> system to a later Debian version?
> 

In general, I'd really suggest running the latest Debian stable.

> 
> In particular, I'm wishing to get a Debian 9 system to run on an MSI 
> H410M-PRO-C board, with an Intel Pentium G6405 CPU.  Have updated to 
> latest backport kernel, and firmware packages.  For the most part 
> everything works fine, however Xorg is falling back to using fbdev 
> graphic driver.
> 

Intel firmware needed as others have suggested.

> 
> This system is used in an offline application, and I'm not ready to 
> upgrade to Debian 11 at this time.
> 
> 
> Thanks, Allen
> 
> Please CC me.  I only get the debian-digest mailings
> 

With every good wish, as ever,

Andy Cater

[toc] | [prev] | [standalone]


Back to top | Article view | linux.debian.user


csiph-web